@@ -342,8 +342,12 @@ class Cursor(common.DBAPICursor):
             self.fetch_batch()
             if len(self._batch) == 0:
                 return None
-        batchRecords = self._batch
-        return batchRecords
+        self._rownumber += len(self._batch)
+        if self._rownumber <= 1000:
+            _logger.info("e6x - Breaking the loop after 1000 e6x - fetch many records")
+            return self._batch
+        # batchRecords = self._batch
+        # return batchRecords
 
 
 def poll(self, get_progress_update=True):
@@ -388,12 +392,12 @@ if __name__ == '__main__':
     cursor.execute("select * from date_dim;")
     bdata = cursor.fetchone()
     try:
-        #if len(bdata) < 1000:
-            print(bdata)
-            print('total rows in the batch resultset ', len(bdata))
-            r_count = cursor.rowcount()
-            print('total row count', r_count)
-            # list(islice(iter(bdata, None), 10000))
+        # if len(bdata) < 1000:
+        print(bdata)
+        print('total rows in the batch resultset ', len(bdata))
+        r_count = cursor.rowcount()
+        print('total row count', r_count)
+        # list(islice(iter(bdata, None), 10000))
     except Exception as e:
         print('Error Message ', e.__cause__)
         cursor.close()
